import { _S3Object, _UnmarshalledS3Object } from "./_S3Object";
/**
 * <p>Provides the input image either as bytes or an S3 object.</p> <p>You pass image bytes to an Amazon Rekognition API operation by using the <code>Bytes</code> property. For example, you would use the <code>Bytes</code> property to pass an image loaded from a local file system. Image bytes passed by using the <code>Bytes</code> property must be base64-encoded. Your code may not need to encode image bytes if you are using an AWS SDK to call Amazon Rekognition API operations. </p> <p>For more information, see Analyzing an Image Loaded from a Local File System in the Amazon Rekognition Developer Guide.</p> <p> You pass images stored in an S3 bucket to an Amazon Rekognition API operation by using the <code>S3Object</code> property. Images stored in an S3 bucket do not need to be base64-encoded.</p> <p>The region for the S3 bucket containing the S3 object must match the region you use for Amazon Rekognition operations.</p> <p>If you use the AWS CLI to call Amazon Rekognition operations, passing image bytes using the Bytes property is not supported. You must first upload the image to an Amazon S3 bucket and then call the operation using the S3Object property.</p> <p>For Amazon Rekognition to process an S3 object, the user must have permission to access the S3 object. For more information, see Resource Based Policies in the Amazon Rekognition Developer Guide. </p>
 */
export interface _Image {
    /**
     * <p>Blob of image bytes up to 5 MBs.</p>
     */
    Bytes?: ArrayBuffer | ArrayBufferView | string;
    /**
     * <p>Identifies an S3 object as the image source.</p>
     */
    S3Object?: _S3Object;
}
export interface _UnmarshalledImage extends _Image {
    /**
     * <p>Blob of image bytes up to 5 MBs.</p>
     */
    Bytes?: Uint8Array;
    /**
     * <p>Identifies an S3 object as the image source.</p>
     */
    S3Object?: _UnmarshalledS3Object;
}
